from django.conf.urls import patterns, url
from .notifications import notification_view
from django.views.generic import TemplateView

urlpatterns = patterns("",
                       url(r"^notification/$", notification_view, name="django-fastbill-notification"),
                       url(r"^checkout/error/$", TemplateView.as_view(template_name="django_fastbill/checkout_error.html"),
                           name="django-fastbill-error-url")
)


#!/usr/bin/env python
# encoding: utf-8

from setuptools import setup

try:
    long_description = open('README.md', 'r').read()
except IOError:
    long_description = "fastbill"

setup(
    name='django-fastbill',
    version="0.1.5",
    description='A thin python wrapper for the fastbill API',
    long_description=long_description,
    author='Jannis Gebauer',
    author_email='ja.geb@pricemesh.io',
    url='http://github.com/jayfk/django-fastbill',
    license='MIT License',
    packages=['django_fastbill', "django_fastbill.management.commands",],
    install_requires=[
        'requests', 'fastbill'
    ],
    setup_requires=["nose>=1.0", "httpretty==0.6.3"],
    test_suite="nose.collector",
    keywords='fastbill api'
)